#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chunked-data
version:              0.3.1
visibility:           public
id:                   chunked-data-0.3.1-Igqf3t5tHwZ5pnn381rixz
key:                  chunked-data-0.3.1-Igqf3t5tHwZ5pnn381rixz
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Typeclasses for dealing with various chunked data representations

description:
    See docs and README at <http://www.stackage.org/package/chunked-data>

category:             Data
abi:                  92c11eca571d7c9573fc7284ab6c1383
exposed:              True
exposed-modules:      Data.Builder Data.ChunkedZip Data.IOData
hidden-modules:       Paths_chunked_data
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chunked-data-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chunked-data
hs-libraries:         HSchunked-data-0.3.1-Igqf3t5tHwZ5pnn381rixz
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7 text-2.0.2
    transformers-0.6.1.0 vector-0.13.2.0-7HrFQCkgeKZFLrimW7Ifgg

haddock-interfaces:
    /usr/share/doc/haskell-chunked-data/html/chunked-data.haddock

haddock-html:         /usr/share/doc/haskell-chunked-data/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

